| bash | R Documentation |
bash() is deprecated because we no longer use or recommend this workflow.
Open bash shell in package directory
bash(pkg = ".")
pkg |
The package to use, can be a file path to the package or a
package object. See |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.