clean_vignettes() is deprecated because build_vignettes() is deprecated.
Arguments
- pkg
The package to use, can be a file path to the package or a package object. See
as.package()for more information.
clean_vignettes() is deprecated because build_vignettes() is deprecated.
The package to use, can be a file path to the package or a
package object. See as.package() for more information.