git_checks: Git checks

View source: R/check-git.R

git_checksR Documentation

Git checks

Description

This function performs Git checks checks prior to release. It is called automatically by release().

Usage

git_checks(pkg = ".")

Arguments

pkg

The package to use, can be a file path to the package or a package object. See as.package() for more information.


devtools documentation built on March 14, 2026, 5:06 p.m.