show_news: Show package news

View source: R/show-news.R

show_newsR Documentation

Show package news

Description

[Deprecated]

show_news() is deprecated because we no longer use or recommend this workflow.

Usage

show_news(pkg = ".", latest = TRUE, ...)

Arguments

pkg

The package to use, can be a file path to the package or a package object. See as.package() for more information.

latest

if TRUE, only show the news for the most recent version.

...

other arguments passed on to news


devtools documentation built on March 14, 2026, 5:06 p.m.