Skip to content

[Deprecated]

bash() is deprecated because we no longer use or recommend this workflow. Open bash shell in package directory

Usage

bash(pkg = ".")

Arguments

pkg

The package to use, can be a file path to the package or a package object. See as.package() for more information.