| build_rmd | R Documentation |
build_rmd() is deprecated, as it is a low-level helper for internal use. To
render your package's README.qmd or README.Rmd, use build_readme(). To
preview a vignette or article, use functions like pkgdown::build_site() or
pkgdown::build_article().
build_rmd(files, path = ".", output_options = list(), ..., quiet = TRUE)
files |
The Rmarkdown files to be rendered. |
path |
path to the package to build the readme. |
output_options |
List of output options that can override the options
specified in metadata (e.g. could be used to force |
... |
additional arguments passed to |
quiet |
If |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.