build_vignettes() is deprecated because we no longer recommend that you
build vignettes in this way, because it leaves build artifacts in your
development directory. Instead, use pkgdown::build_article() to
render articles locally for preview and polishing.
Usage
build_vignettes(
pkg = ".",
dependencies = "VignetteBuilder",
clean = TRUE,
upgrade = "never",
quiet = FALSE,
install = TRUE,
keep_md = TRUE
)Arguments
- pkg
The package to use, can be a file path to the package or a package object. See
as.package()for more information.- dependencies
Which dependencies do you want to check? Can be a character vector (selecting from "Depends", "Imports", "LinkingTo", "Suggests", or "Enhances"), or a logical vector.
TRUEis shorthand for "Depends", "Imports", "LinkingTo" and "Suggests".NAis shorthand for "Depends", "Imports" and "LinkingTo" and is the default.FALSEis shorthand for no dependencies (i.e. just check this package, not its dependencies).The value "soft" means the same as
TRUE, "hard" means the same asNA.You can also specify dependencies from one or more additional fields, common ones include:
Config/Needs/website - for dependencies used in building the pkgdown site.
Config/Needs/coverage for dependencies used in calculating test coverage.
- clean
Remove all files generated by the build, even if there were copies there before.
- upgrade
Should package dependencies be upgraded? One of "default", "ask", "always", or "never". "default" respects the value of the
R_REMOTES_UPGRADEenvironment variable if set, and falls back to "ask" if unset. "ask" prompts the user for which out of date packages to upgrade. For non-interactive sessions "ask" is equivalent to "always".TRUEandFALSEare also accepted and correspond to "always" and "never" respectively.- quiet
If
TRUE, suppresses most output. Set toFALSEif you need to debug.- install
If
TRUE, install the package before building vignettes.- keep_md
If
TRUE, move md intermediates as well as rendered outputs. Most useful when using thekeep_mdYAML option for Rmarkdown outputs.