| check_doc_fields | R Documentation |
Checks all Rd files in man/ and looks for any that have a \usage section
(i.e. a function) but that don't have \value and \examples sections.
These missing fields are flagged by CRAN on initial submission.
check_doc_fields(pkg = ".", fields = c("value", "examples"))
pkg |
The package to use, can be a file path to the package or a
package object. See |
fields |
A character vector of Rd field names to check for. |
A named list of character vectors, one for each field, containing the names of Rd files missing that field. Returned invisibly.
## Not run:
check_doc_fields(".")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.