check_mac_release: Check a package on macOS

View source: R/check-mac.R

check_mac_releaseR Documentation

Check a package on macOS

Description

Check on either the released or development versions of R, using https://mac.r-project.org/macbuilder/submit.html.

Usage

check_mac_release(
  pkg = ".",
  dep_pkgs = character(),
  args = NULL,
  manual = TRUE,
  quiet = FALSE,
  ...
)

check_mac_devel(
  pkg = ".",
  dep_pkgs = character(),
  args = NULL,
  manual = TRUE,
  quiet = FALSE,
  ...
)

Arguments

pkg

The package to use, can be a file path to the package or a package object. See as.package() for more information.

dep_pkgs

Additional custom dependencies to install prior to checking the package.

args

An optional character vector of additional command line arguments to be passed to ⁠R CMD build⁠ if binary = FALSE, or ⁠R CMD install⁠ if binary = TRUE.

manual

Should the manual be built?

quiet

If TRUE, suppresses output.

...

Additional arguments passed to pkgbuild::build().

Value

The url with the check results (invisibly)

See Also

Other build functions: check_win()


devtools documentation built on March 14, 2026, 5:06 p.m.