| dev_sitrep | R Documentation |
Call this function if things seem weird and you're not sure what's wrong or how to fix it. It reports:
If R is up to date.
If RStudio or Positron is up to date.
If compiler build tools are installed and available for use.
If devtools and its dependencies are up to date.
If the package's dependencies are up to date.
dev_sitrep(pkg = ".", debug = FALSE)
pkg |
The package to use, can be a file path to the package or a
package object. See |
debug |
If |
A named list, with S3 class dev_sitrep (for printing purposes).
## Not run:
dev_sitrep()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.