Skip to content

[Deprecated]

reload() is deprecated because we no longer use or recommend this workflow. Instead, we recommend load_all() to load a package for interactive development.

Usage

reload(pkg = ".", quiet = FALSE)

Arguments

pkg

The package to use, can be a file path to the package or a package object. See as.package() for more information.

quiet

if TRUE suppresses output from this function.

See also

load_all() to load a package for interactive development.