| submit_cran | R Documentation |
This submits your package to CRAN using the web-form submission process. To complete the submission you will need respond to the email sent to the maintainer email address.
We generally recommend using this part of the process defined by
usethis::use_release_issue(); this process maximizes the chances of a successful
submission.
submit_cran(pkg = ".", args = NULL)
pkg |
The package to use, can be a file path to the package or a
package object. See |
args |
An optional character vector of additional command
line arguments to be passed to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.