Skip to content

[Deprecated]

wd() is deprecated because we no longer use or recommend this workflow. Set working directory

Usage

wd(pkg = ".", path = "")

Arguments

pkg

The package to use, can be a file path to the package or a package object. See as.package() for more information.

path

path within package. Leave empty to change working directory to package directory.