| wd | R Documentation |
wd() is deprecated because we no longer use or recommend this workflow.
Set working directory
wd(pkg = ".", path = "")
pkg |
The package to use, can be a file path to the package or a
package object. See |
path |
path within package. Leave empty to change working directory to package directory. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.